<template>
  <div class="mod-config">
    <basic-container>
      <ttable
        :table="table"
        @handleSelectionChange="handleSelectionChange"
        :uploadInfo="uploadInfo"
        :prelang="prelang"
        :options="options"
        :ajaxFun="ajaxFun"
        ref="equipmentTable"
      >
        <template #toolbar></template>
      </ttable>
      <!-- 弹窗, 新增 / 修改 -->
      <table-form
        v-if="addOrUpdateVisible"
        ref="addOrUpdate"
        @refreshDataList="getData"
      ></table-form>
    </basic-container>
  </div>
</template>

<script>
import { delObj, fetchList } from '@/api/equipment/equipment'
import TableForm from './equipment-form'
import ttable from '@/views/common/ztt-table.vue'
import { mapGetters } from 'vuex'
import * as fecha from 'element-ui/lib/utils/date'
import { remote } from '../../../api/admin/dict'
export default {
  data() {
    return {
      ajaxFun: fetchList,
      multipleSelection: [],
      uploadInfo: {
        // 是否展示上传EXCEL以及对应的url
        isShow: true,
        url: '/mes/equipment/upload'
      },
      prelang: 'workstation',
      options: {
        height: 300, // 默认高度-为了表头固定
        stripe: true, // 是否为斑马纹 table
        highlightCurrentRow: false, // 是否要高亮当前行
        border: true, // 是否有纵向边框
        lazy: false, // 是否需要懒加载
        fit: true, // 列的宽度是否自撑开
        multiSelect: true, //
        seqNo: true,
        isRefresh: true, // 是否显示刷新按钮
        isShowHide: true, // 是否显示显影按钮
        isSearch: false, // 高级查询按钮
        defaultOrderBy: { column: 'manufactureDate', direction: 'desc' }
      },
      table: {
        total: 0,
        currentPage: 1,
        pageSize: 20,
        data: [],
        // 标题
        column: [
          // 设备编号
          {
            minWidth: '30',
            prop: 'number',
            label: '设备编号',
            sort: true,
            isTrue: true,
            formatter: (row, column, cellValue) => {
              return cellValue
            },
            isSearch: true,
            searchInfoType: 'text'
          },
          // 设备名称
          {
            minWidth: '30',
            prop: 'name',
            label: '设备名称',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          // 工厂
          {
            minWidth: '30',
            prop: 'factoryName',
            label: '工厂',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'text'
          },
          {
            minWidth: '30',
            prop: 'workshop',
            label: '所属车间',
            sort: true,
            isTrue: true,
            isSearch: true,
            searchInfoType: 'select',
            formatter: this.workShopFormatter,
            optList: () => {
              return this.workshopList
            }
          },
          // 位置
          {
            minWidth: '30',
            prop: 'position',
            label: '位置',
            sort: true,
            isTrue: true,
            isSearch: false,
            searchInfoType: 'text'
          },
          // 邮箱
          {
            minWidth: '30',
            prop: 'email',
            label: '邮箱',
            sort: true,
            isTrue: true,
            isSearch: false,
            searchInfoType: 'text'
          },
          // 供应商
          {
            minWidth: '30',
            prop: 'supplier',
            label: '供应商',
            sort: true,
            isTrue: true,
            isSearch: false,
            searchInfoType: 'text'
          },
          // 制造商
          {
            minWidth: '30',
            prop: 'manufacturer',
            label: '制造商',
            sort: true,
            isTrue: true,
            isSearch: false,
            searchInfoType: 'text'
          },
          // 型号规格
          {
            minWidth: '30',
            prop: 'typeSpecification',
            label: '型号规格',
            sort: true,
            isTrue: true,
            isSearch: false,
            searchInfoType: 'text'
          },
          // 制造日期
          {
            minWidth: '150',
            width: '250',
            prop: 'manufactureDate',
            label: '制造日期',
            sort: true,
            isTrue: true,
            formatter: this.formatReceiveTime,
            isSearch: true,
            searchInfoType: 'datetimerange'
          },
          // 安装日期
          {
            minWidth: '150',
            width: '250',
            prop: 'installDate',
            label: '安装日期',
            sort: true,
            isTrue: true,
            isSearch: true,
            formatter: this.formatReceiveTime,
            searchInfoType: 'datetimerange'
          },
          // 状态
          {
            minWidth: '30',
            prop: 'state',
            label: '状态',
            sort: true,
            isTrue: true,
            isSearch: false,
            searchInfoType: 'text'
          }
        ],
        toolbar: [
          {
            text: '新增',
            type: 'primary',
            fun: this.addOrUpdateHandle
          }
        ],
        operator: [
          {
            text: '修改',
            icon: 'el-icon-edit',
            type: 'text',
            size: 'small',
            fun: this.addOrUpdateHandle
          },
          {
            text: '删除',
            icon: 'el-icon-delete',
            type: 'text',
            size: 'small',
            fun: this.deleteHandle
          }
        ],
        operatorConfig: {
          fixed: 'right',
          label: '操作',
          width: 130,
          minWidth: 130
        }
      },
      addOrUpdateVisible: false,
      workshopList: []
    }
  },
  components: {
    ttable,
    TableForm
  },
  computed: {
    ...mapGetters(['permissions'])
  },
  created() {
    remote('work_shop').then((response) => {
      if (response.data.code === 0) {
        this.workshopList = response.data.data
      } else {
        this.workshopList = []
      }
    })
  },
  methods: {
    workShopFormatter(row, column, cellValue) {
      this.workshopList.forEach((obj) => {
        if (obj.value == cellValue) {
          cellValue = obj.label
        }
      })
      return cellValue
    },
    // 获取数据列表
    getData() {
      this.$refs.equipmentTable.getDataList()
    },
    formatReceiveTime(row, column, cellValue) {
      return cellValue ? fecha.format(new Date(cellValue), 'yyyy-MM-dd') : ''
    },
    handleSelectionChange(val) {
      this.multipleSelection = val
    },
    // 新增 / 修改
    addOrUpdateHandle(row) {
      this.addOrUpdateVisible = true
      this.$nextTick(() => {
        this.$refs.addOrUpdate.init(row == null ? null : row.id)
      })
    },
    // 删除
    deleteHandle(row) {
      this.$confirm('是否确认删除设备名称为' + row.name, '提示', {
        confirmButtonText: '确定',
        cancelButtonText: '取消',
        closeOnClickModal: false,
        type: 'warning'
      })
        .then(function() {
          return delObj(row.id)
        })
        .then((data) => {
          this.$message.success('删除成功')
          this.getData()
        })
    }
  }
}
</script>
